@@ -1,4 +1,5 @@
-# Copyright 2020 ADTRAN, Inc.
+# Copyright 2020-present Open Networking Foundation
+# Original copyright 2020-present ADTRAN, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,9 +36,3 @@ class NativeEventsManagementService(Service):
     @is_connected
     def hw_event_mgmt_service_update_events_configuration(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.UpdateEventsConfiguration, hw_events_mgmt_service_pb2.EventsConfigurationRequest, param_dict, **kwargs)
-
-    # rpc StreamEvents(google.protobuf.Empty) returns(stream Event);
-    @keyword
-    @is_connected
-    def hw_event_mgmt_service_stream_events(self, **kwargs):
-        return self._grpc_helper(self.stub.StreamEvents, **kwargs)
