@@ -1,4 +1,5 @@
-# Copyright 2020 ADTRAN, Inc.
+# Copyright 2020-present Open Networking Foundation
+# Original copyright 2020-present ADTRAN, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -101,15 +102,3 @@ class NativeHWManagementService(Service):
     @is_connected
     def hw_management_service_get_log_level(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.GetLogLevel, hw_management_service_pb2.GetLogLevelRequest, param_dict, **kwargs)
-
-    # rpc HeartbeatCheck(google.protobuf.Empty) returns (Heartbeat);
-    @keyword
-    @is_connected
-    def hw_management_service_heartbeat_check(self, **kwargs):
-        return self._grpc_helper(self.stub.HeartbeatCheck, **kwargs)
-
-    # rpc RebootDevice(RebootDeviceRequest) returns(RebootDeviceResponse);
-    @keyword
-    @is_connected
-    def hw_management_service_reboot_device(self, param_dict, **kwargs):
-        return self._grpc_helper(self.stub.RebootDevice, hw_management_service_pb2.RebootDeviceRequest, param_dict, **kwargs)
